@@ -1,16 +1,11 @@
-# Copyright (C) 2016, the Pyzo development team
-#
-# Pyzo is distributed under the terms of the 2-Clause BSD License.
-# The full license can be found in 'license.txt'.
-
-
-""" Module shellInfoDialog
+"""Module shellInfoDialog
 
 Implements shell configuration dialog.
 
 """
 
-import os, sys
+import os
+import sys
 from pyzo.qt import QtCore, QtGui, QtWidgets  # noqa
 
 import pyzo
@@ -269,7 +264,11 @@ class ShellInfo_pythonPath(ShellinfoWithSystemDefault):
 class ShellInfo_startupScript(QtWidgets.QVBoxLayout):
     DISABLE_SYSTEM_DEFAULT = sys.platform == "darwin"
     SYSTEM_VALUE = "$PYTHONSTARTUP"
-    RUN_AFTER_GUI_TEXT = "# AFTER_GUI - code below runs after integrating the GUI\n"
+    RUN_BEFORE_AFTER_GUI_TEXT = (
+        "... Python code to run before integrating the GUI ...\n"
+        "# AFTER_GUI\n"
+        "... Python code to run after integrating the GUI ..."
+    )
 
     def __init__(self, parent):
         # Do not pass parent, because is a sublayout
@@ -288,6 +287,7 @@ class ShellInfo_startupScript(QtWidgets.QVBoxLayout):
         self._edit2.setMaximumHeight(80)
         self._edit2.setMinimumWidth(200)
         self._edit2.textChanged.connect(self.onEditChanged)
+        self._edit2.setPlaceholderText(self.RUN_BEFORE_AFTER_GUI_TEXT)
 
         # Layout
         self.setSpacing(1)
@@ -375,7 +375,7 @@ class ShellInfo_startupScript(QtWidgets.QVBoxLayout):
             self._edit1.hide()
             self._edit2.show()
             if not value.strip():
-                value = self.RUN_AFTER_GUI_TEXT
+                value = ""  # this will display the placeholder text
             self._edit2.setText(value)
 
     def getTheText(self):
@@ -433,7 +433,7 @@ class ShellInfoTab(QtWidgets.QScrollArea):
         translate(
             "shell",
             "pythonPath ::: A list of directories to search for modules and packages. Write each path on a new line, or separate with the default seperator for this OS.",
-        ),  # noqa
+        ),
         translate(
             "shell",
             "startupScript ::: The script to run at startup (not in script mode).",
