@@ -1,9 +1,4 @@
-# Copyright (C) 2013, the Pyzo development team
-#
-# Pyzo is distributed under the terms of the 2-Clause BSD License.
-# The full license can be found in 'license.txt'.
-
-""" pyzowizard module
+"""pyzowizard module
 
 Implements a wizard to help new users get familiar with pyzo.
 
@@ -109,7 +104,9 @@ class BasePyzoWizardPage(QtWidgets.QWizardPage):
         self._text_label = QtWidgets.QLabel(self)
         self._text_label.setTextFormat(QtCore.Qt.TextFormat.RichText)
         self._text_label.setWordWrap(True)
-        self._text_label.setTextInteractionFlags(QtCore.Qt.TextInteractionFlag.TextSelectableByMouse)
+        self._text_label.setTextInteractionFlags(
+            QtCore.Qt.TextInteractionFlag.TextSelectableByMouse
+        )
 
         # Create label for image
         self._comicLabel = QtWidgets.QLabel(self)
@@ -418,7 +415,6 @@ class DebuggingWizardPage1(BasePyzoWizardPage):
         you can see local variables in different layers of nested function calls.
         Continuing execution is not possible in postmortem, though.""",
         ),
-
         translate(
             "wizard",
             """The *Pause* debug action (in the "Shell" menu or shell toolbar) makes it
@@ -563,10 +559,11 @@ class AdvAutoCompWizardPage(BasePyzoWizardPage):
         <br />
         The Ctrl+Space hot key can also be pressed while having already entered some characters
         of the attribute, key or arguments, in case the autocompletion list widget resp. calltip
-        should be shown again after having cancelled it."""
+        should be shown again after having cancelled it.""",
         ),
     ]
 
+
 class MiscellaneousWizardPage(BasePyzoWizardPage):
     _title = translate("wizard", "Miscellaneous tips and tricks")
     _image_filename = ""
@@ -596,10 +593,11 @@ class MiscellaneousWizardPage(BasePyzoWizardPage):
         <br />
         You can directly modify Pyzo's source code even in the binary distribution because
         the binary is just a Python-Interpreter that runs the Python source code in the
-        installation directory. See the "About Pyzo" dialog for the code location."""
+        installation directory. See the "About Pyzo" dialog for the code location.""",
         ),
     ]
 
+
 class FinalPage(BasePyzoWizardPage):
     _title = translate("wizard", "Get coding!")
     _image_filename = "pyzologo128.png"
